BioSimulators-MASSpy documentation — BioSimulators-MASSpy 0.0.5 documentation

# BioSimulators-MASSpy documentation

BioSimulators-MASSpy provides a BioSimulators-compliant command-line interface to the MASSpy tool for kinetic simulation of metabolic reaction networks. A Docker image for this package is also available.

This command-line interface and Docker image enable users to use MASSpy to execute COMBINE/OMEX archives that describe one or more simulation experiments (in SED-ML format) of one or more kinetic models of metabolic networks in the MASSpy schema for the SBML format.

A list of the algorithms and algorithm parameters supported by MASSpy is available at BioSimulators.

A simple web application and web service for using MASSpy to execute COMBINE/OMEX archives is also available at runBioSimulations.

## Contents

- Installation instructions
  - Command-line program
  - Docker image with a command-line entrypoint
- Tutorial
  - Creating COMBINE/OMEX archives and encoding simulation experiments into SED-ML
  - Command-line program
  - Docker image with a command-line entrypoint
- API documentation
  - Submodules
  - biosimulators_masspy.core module
  - biosimulators_masspy.data_model module
- About BioSimulators-MASSpy
  - License
  - Development team
  - Questions and comments
- Index